==> networkcommons-0.4.1.tar.gz: networkcommons-0.4.1/README.md <==
# NetworkCommons - Bridging the gap between data, methods and knowledge in the network inference field

NetworkCommons is a community-driven platform designed to simplify access to tools and resources for inferring context-specific protein interaction networks by integrating context-agnostic prior knowledge with omics data. These networks have a wide range of applications, from omics data interpretation to identifying drug targets and key driver mutations.

[![codecov][badge-cov]][link-cov]
[![Tests][badge-tests]][link-tests]
[![Documentation][badge-docs]][link-docs]

[![NetworkCommons API](./docs/src/_static/nc_graphabs.svg)](https://networkcommons.readthedocs.io)

Addressing the complexity and fragmentation of data, methods, and tools across multiple repositories, NetworkCommons offers an API that provides access to raw and preprocessed omics data, directed and/or signed template graphs, and various network inference methods. By streamlining accessibility, we aim to support systematic benchmarking, enhance critical assessment, and foster collaborative advancements in network biology.

We welcome any contribution to this project! For more information, please check [our documentation](https://networkcommons.readthedocs.io). 

## Contributors

Martin Garrido-Rodriguez, Olga Ivanova, Victor Paton, Denes Turei

[badge-cov]: https://codecov.io/github/saezlab/networkcommons/graph/badge.svg?token=RH438ALJC2
[link-cov]: https://codecov.io/github/saezlab/networkcommons
[badge-tests]: https://img.shields.io/github/actions/workflow/status/saezlab/networkcommons/test.yaml?branch=main
[link-tests]: https://github.com/saezlab/networkcommons/actions/workflows/test.yml
[badge-docs]: https://img.shields.io/readthedocs/networkcommons
[link-docs]: https://networkcommons.readthedocs.io

==> networkcommons-0.4.2.tar.gz: networkcommons-0.4.2/README.md <==
# NetworkCommons - Bridging the gap between data, methods and knowledge in the network inference field

NetworkCommons is a community-driven platform designed to simplify access to tools and resources for inferring context-specific protein interaction networks by integrating context-agnostic prior knowledge with omics data. These networks have a wide range of applications, from omics data interpretation to identifying drug targets and key driver mutations.

[![codecov][badge-cov]][link-cov]
[![Tests][badge-tests]][link-tests]
[![Documentation][badge-docs]][link-docs]

[![NetworkCommons API](https://raw.githubusercontent.com/saezlab/networkcommons/0d62d40ad0b3c7ab40b61f4f236af69ce9fa019f/docs/src/_static/nc_graphabs.svg)](https://networkcommons.readthedocs.io)

Addressing the complexity and fragmentation of data, methods, and tools across multiple repositories, NetworkCommons offers an API that provides access to raw and preprocessed omics data, directed and/or signed template graphs, and various network inference methods. By streamlining accessibility, we aim to support systematic benchmarking, enhance critical assessment, and foster collaborative advancements in network biology.

We welcome any contribution to this project! For more information, please check [our documentation](https://networkcommons.readthedocs.io). 

## Contributors

Martin Garrido-Rodriguez, Olga Ivanova, Victor Paton, Denes Turei

[badge-cov]: https://codecov.io/github/saezlab/networkcommons/graph/badge.svg?token=RH438ALJC2
[link-cov]: https://codecov.io/github/saezlab/networkcommons
[badge-tests]: https://img.shields.io/github/actions/workflow/status/saezlab/networkcommons/test.yaml?branch=main
[link-tests]: https://github.com/saezlab/networkcommons/actions/workflows/test.yml
[badge-docs]: https://img.shields.io/readthedocs/networkcommons
[link-docs]: https://networkcommons.readthedocs.io
